# OpenSAFELY Command Line Interface

This tool is part of the [OpenSAFELY](https://www.opensafely.org)
project.

To use it you will need to install:
 * [Python](https://www.python.org/downloads/) (at least version 3.8, but the more recent the better)
 * [git](https://git-scm.com/downloads)
 * [Docker](https://docs.docker.com/get-docker/)

Once these are installed you can install the tool itself with:
```
pip install opensafely
```

To see available commands run
```
opensafely --help
```

## Developer docs

Please see [the additional information](DEVELOPERS.md).
